# audioevaluator 
audioevaluator is a simple, easy-to-use wrapper for performing Automatic Speech Recognition with PyTorch. 

It is being used as a supporting package for Earudite, a trivia game, to evaluate recording quality relative to a transcript.